function [A,M,V] = assemble_AM(x,t,Para);

% Antoine-Besse July 2006
% Assembling of the finite element mass matrix
% for the potential term.
% Linear Finite Elements
% N : number of interior points
% dx : mesh size
% TBC on x0 and x1

% -------------------------------------------------------------------------
% The function f stands for the potential
f  = @(x) potential_func(x);

fx = f(x);
pot = false;
if any(fx)
  pot = true;
end
  
% -------------------------------------------------------------------------
% The following f function allows to verify that we have
% the good mass matrix if the potential equal one.
% f = @(x) 1;

% -------------------------------------------------------------------------
% The following f function allows to get a null potential.
% f=@(x) 0;

% -------------------------------------------------------------------------
% P1 finite element basis functions

g1 = @(x,xl,xu) (xu-x)./(xu-xl);
g2 = @(x,xl,xu) (x-xl)./(xu-xl);


M_loc = 1/6 *[ 2 , 1; ...
	      1 , 2]; 

A_loc = [ 1 , -1; ...
	 -1 , 1]; 

ndof = size(x,1);
MV = spalloc(ndof,ndof,2*ndof);
M = spalloc(ndof,ndof,2*ndof);
A = spalloc(ndof,ndof,2*ndof);
V = spalloc(ndof,ndof,2*ndof);

for jj = 1:size(t,1)
  
  dx =  x(t(jj,2))-x(t(jj,1));
  M(t(jj,1):t(jj,2),t(jj,1):t(jj,2)) = M(t(jj,1):t(jj,2),t(jj,1):t(jj,2)) + dx*M_loc;
  A(t(jj,1):t(jj,2),t(jj,1):t(jj,2)) = A(t(jj,1):t(jj,2),t(jj,1):t(jj,2)) + (1/dx)*A_loc;
  if pot
  xl = x(t(jj,1));
  xu = x(t(jj,2));
  f11 = @(x) f(x).*g1(x,xl,xu).*g1(x,xl,xu);
  f12 = @(x) f(x).*g1(x,xl,xu).*g2(x,xl,xu);
  f22 = @(x) f(x).*g2(x,xl,xu).*g2(x,xl,xu);
  El11=quad(f11,xl,xu);
  El12=quad(f12,xl,xu);
  El22=quad(f22,xl,xu);
  El1=[ El11 , El12; ...
	El12 , El22];    
  V(t(jj,1):t(jj,2),t(jj,1):t(jj,2))= V(t(jj,1):t(jj,2),t(jj,1):t(jj,2)) + El1;
  end
end
