function [A,M,V] = assemble_AM(x,t,dof,Para);

% Antoine-Besse July 2006
% Assembling of the finite element mass matrix
% for the potential term.
% Linear Finite Elements
% N : number of interior points
% dx : mesh size
% TBC on x0 and x1

% -------------------------------------------------------------------------
% The function f stands for the potential
f  = @(x) potential_func(x);

fx = f(x);
pot = false;
if any(fx)
  pot = true;
end
  
% -------------------------------------------------------------------------
% The following f function allows to verify that we have
% the good mass matrix if the potential equal one.
% f = @(x) 1;

% -------------------------------------------------------------------------
% The following f function allows to get a null potential.
% f=@(x) 0;

% -------------------------------------------------------------------------
% P2 finite element basis functions
g1 = @(x,xl,xu) 2*(x-(xl+xu)/2).*(x-xu)./(xu-xl).^2;
g2 = @(x,xl,xu) -4*(x-xl).*(x-xu)./(xu-xl).^2;
g3 = @(x,xl,xu) 2*(x-xl).*(x-(xl+xu)/2)./(xu-xl).^2;

% g1 = @(x,k) 2*(x-(k-0.5)*dx).*(x-k*dx)/dx^2;
% g2 = @(x,k) -4*(x-(k-1)*dx).*(x-k*dx)/dx^2;
% g3 = @(x,k) 2*(x-(k-0.5)*dx).*(x-(k-1)*dx)/dx^2;


M_loc = [2/15 1/15 -1/30;
	1/15 8/15 1/15;
	-1/30 1/15 2/15];
A_loc = [7/3 -8/3 1/3;
	-8/3 16/3 -8/3;
	1/3 -8/3 7/3]; 

ndof = 2*size(x,1)-1;
MV = spalloc(ndof,ndof,3*ndof);
M = spalloc(ndof,ndof,3*ndof);
A = spalloc(ndof,ndof,3*ndof);
V = spalloc(ndof,ndof,3*ndof);

for jj = 1:size(t,1)
  
  dx =  x(t(jj,2))-x(t(jj,1));
  M(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) = M(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + dx*M_loc;
  A(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) = A(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + (1/dx)*A_loc;
  if pot
  xl = x(t(jj,1));
  xu = x(t(jj,2));
  f11 = @(x) f(x).*g1(x,xl,xu).*g1(x,xl,xu);
  f12 = @(x) f(x).*g1(x,xl,xu).*g2(x,xl,xu);
  f13 = @(x) f(x).*g1(x,xl,xu).*g3(x,xl,xu);
  f22 = @(x) f(x).*g2(x,xl,xu).*g2(x,xl,xu);
  f23 = @(x) f(x).*g2(x,xl,xu).*g3(x,xl,xu);
  f33 = @(x) f(x).*g3(x,xl,xu).*g3(x,xl,xu);
  El11=quad(f11,xl,xu);
  El12=quad(f12,xl,xu);
  El13=quad(f13,xl,xu);
  El22=quad(f22,xl,xu);
  El23=quad(f23,xl,xu);
  El33=quad(f33,xl,xu);
  El1=[ El11 , El12, El13; ...
	El12 , El22, El23;
        El13 , El23, El33];    
  V(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2))= V(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + El1;
  end
end
