function [A,M,V] = assemble_AM(x,t,dof,Para);

% Antoine-Besse July 2006
% Assembling of the finite element mass matrix
% for the potential term.
% Linear Finite Elements
% N : number of interior points
% dx : mesh size
% TBC on x0 and x1

% -------------------------------------------------------------------------
% The function f stands for the potential
f  = @(x) potential_func(x);

fx = f(x);
pot = false;
if any(fx)
  pot = true;
end
  
% -------------------------------------------------------------------------
% The following f function allows to verify that we have
% the good mass matrix if the potential equal one.
% f = @(x) 1;

% -------------------------------------------------------------------------
% The following f function allows to get a null potential.
% f=@(x) 0;

% -------------------------------------------------------------------------
% P3 finite element basis functions
g1 = @(x,k) -9/2*(x-(k-2/3)*dx).*(x-(k-1/3)*dx).*(x-(k-0)*dx)/dx^3;
g2 = @(x,k) 27/2*(x-(k-1)*dx).*(x-(k-1/3)*dx).*(x-(k-0)*dx)/dx^3;
g3 = @(x,k) -27/2*(x-(k-1)*dx).*(x-(k-2/3)*dx).*(x-(k-0)*dx)/dx^3;
g4 = @(x,k) 9/2*(x-(k-1)*dx).*(x-(k-2/3)*dx).*(x-(k-1/3)*dx)/dx^3;

M_loc = [8/105,   33/560, -3/140,  19/1680;
	33/560,  27/70,  -27/560, -3/140;
	-3/140,  -27/560, 27/70,  33/560;
	19/1680, -3/140,  33/560, 8/105];

A_loc = [37/10,  -189/40, 27/20, -13/40;
	 -189/40, 54/5,  -297/40, 27/20;
	 27/20, -297/40, 54/5,  -189/40;
	 -13/40,  27/20, -189/40,  37/10];


ndof = 3*size(x,1)-2;
MV = spalloc(ndof,ndof,4*ndof);
M = spalloc(ndof,ndof,4*ndof);
A = spalloc(ndof,ndof,4*ndof);
V = spalloc(ndof,ndof,4*ndof);

for jj = 1:size(t,1)
  
  dx =  x(t(jj,2))-x(t(jj,1));
  M(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) = M(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + dx*M_loc;
  A(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) = A(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + (1/dx)*A_loc;
  if pot
  xl = x(t(jj,1));
  xu = x(t(jj,2));
  f11 = @(x) f(x).*g1(x,xl,xu).*g1(x,xl,xu);
  f12 = @(x) f(x).*g1(x,xl,xu).*g2(x,xl,xu);
  f13 = @(x) f(x).*g1(x,xl,xu).*g3(x,xl,xu);
  f14 = @(x) f(x).*g1(x,xl,xu).*g4(x,xl,xu);
  f22 = @(x) f(x).*g2(x,xl,xu).*g2(x,xl,xu);
  f23 = @(x) f(x).*g2(x,xl,xu).*g3(x,xl,xu);
  f24 = @(x) f(x).*g2(x,xl,xu).*g4(x,xl,xu);
  f33 = @(x) f(x).*g3(x,xl,xu).*g3(x,xl,xu);
  f34 = @(x) f(x).*g3(x,xl,xu).*g4(x,xl,xu);
  f44 = @(x) f(x).*g4(x,xl,xu).*g4(x,xl,xu);
  El11=quad(f11,xl,xu);
  El12=quad(f12,xl,xu);
  El13=quad(f13,xl,xu);
  El14=quad(f14,xl,xu);
  El22=quad(f22,xl,xu);
  El23=quad(f23,xl,xu);
  El24=quad(f24,xl,xu);
  El33=quad(f33,xl,xu);
  El34=quad(f34,xl,xu);
  El44=quad(f44,xl,xu);
  El1=[ El11 , El12, El13, El14; ...
	El12 , El22, EL23, El24; ...
        El13 , El23, EL33, El34; ...
        El14 , El24  El34, El44];    
  V(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2))= V(dof(jj,1):dof(jj,2),dof(jj,1):dof(jj,2)) + El1;
  end
end
