function [out]=funcpmlfd(data)
% Computation of the solution of the free Schroedinger equation
% by Crank-Nicolson scheme with finite differences method
% with Absorbing Boundary conditions : PML

% data is a cell
%  |
%  |--- data.a
%  |--- data.b
%  |--- data.sigma
%  |--- data.xc
%  |--- data.x0
%  |--- data.x1
%  |--- data.N
%  |--- data.tfinal
%  |--- data.dt
%  |--- data.k0  
%  |--- data.m
%  |--- data.initDatum
%  |--- data.axe1  : where to plot |u|
%  |--- data.axe2  : where to plot contour of log10|u|
%  |--- data.txtiter    : handle on textiter
%  |--- data.txtnbiter  : handle on textnbiter

%  clear all;
% Setting default values
if ~isfield(data,'PlotFlag')
  data.PlotFlag = logical(1);
end
if ~isfield(data,'ReturnFlag')
  data.ReturnFlag = 1;
end

a=data.a;
b=data.b;
savenb=data.savenb;
sigma=data.sigma;
xc=data.xc;
% Wave number
k0=data.k0;

% Data
% Computational domain : [x0,x1]
x0=data.x0;
x1=data.x1;
N=data.N;
geo.x = linspace(x0,x1,N);
x = geo.x.'; gridx = x;
dx = x(2)-x(1);

%PML parameters
M_Left = ceil(0.4*N); 
M_Right = ceil(0.4*N);
sigmad = 1;

PML.Left.M = M_Left;
PML.Left.sigma = sigmad;
PML.Right.M = M_Right;
PML.Right.sigma = sigmad;
% Final time of computation
% dt : time step
% niter : number of iterations
tfinal=data.tfinal;
dt=data.dt;
niter=tfinal/dt;
if data.PlotFlag
  set(data.txtnbiter,'String',num2str(niter));  
end

%--------------------------------------------------------------
%--------------------------------------------------------------
SysMat = getSysMatpmlfd(geo,PML);

KK = a*i/dt*SysMat.M + 1/2*(b*SysMat.L-SysMat.V);
MM = a*i/dt*SysMat.M - 1/2*(b*SysMat.L-SysMat.V);

%[L, U] = lu(KK);
[LA,UA,pA,qA] = lu(KK,'vector');
% Initial datum
%u_n=initialDatum(x,k0);
PROJECTOR = sparse([1:N]+PML.Left.M,[1:N],ones(1,N),N+PML.Right.M+PML.Left.M,N);

u_D = eval(data.initDatum);  
% try
% V = potential_func(data.xc);
% a = data.a;
% b = data.b;
% xc = data.xc;
% k0 = data.k0;
% sigma = data.sigma;
% t = 0;
% u_D = eval(data.exactCpot); 
% %u_n_D([1 end])
% catch
%    warning('Using initDatum') 
% end
u = PROJECTOR * u_D;

sav=1;
% pl : used to store |u^n|
pl=zeros(niter/savenb,N);
pl2=pl;
pl(sav,:)=u_D.';
tl=zeros(niter/savenb,1);
tl(sav)=0;


%--------------------------------------------------------------
%--------------------------------------------------------------

% Iterations
MaxV=max(potential_func(x));
if (MaxV==0)
  MaxV=1;
end

for k=1:niter,
  
  rhs = MM*u;
  u(qA,:)= UA\(LA\rhs(pA,:));
%   u_n1 = U\(L\(MM*u_n));
%   u_n = u_n1;
% Display
  if rem(k,savenb)==0
%      figure(10)
%      plot(x,abs(PROJECTOR.'*u_n),'k:',x,real(PROJECTOR.'*u_n),'m:',x,imag(PROJECTOR.'*u_n),'c:',x,potential_func(x)/MaxV,'r:'); hold on
%      drawnow; pause(0.1)
    
% $$$       fprintf('Iteration %d\n',k);
% $$$       plot(x,abs(u1));axis([x0 x1 0 1]);drawnow;
    sav=sav+1;
    pl(sav,:)=(PROJECTOR.'*u).';
    tl(sav)=k*dt;
    if   data.PlotFlag
    
      plot(x,abs(PROJECTOR.'*u),x,potential_func(x)/MaxV,'r:','parent',data.axe1);axis(data.axe1,[x0 x1 0 1]);drawnow;
      set(data.txtiter,'String',num2str(k));
      if rem(sav,20)==0
	pl2(1:sav,:)=log10(abs(pl(1:sav,:)));
	contourf(x,tl(1:sav),pl2(1:sav,:),[0,-0.5,-1,-2,-3,-3.5,-4,-4.5,-5,-6,-16],...
		 'parent',data.axe2);
	axis(data.axe2,[x0-1 x1+1 0 tfinal]);
	h=colorbar('peer',data.axe2);
	set(h,'fontsize',7);
      end
    end
  end
end
% $$$   figure(2);
% $$$   mesh(x,tl,pl);view(160,60);
if   data.PlotFlag
  
  pl2(1:sav,:)=log10(abs(pl(1:sav,:)));
  contourf(x,tl(1:sav),pl2(1:sav,:),[0,-0.5,-1,-2,-3,-3.5,-4,-4.5,-5,-6,-16],...
	   'parent',data.axe2);
  axis(data.axe2,[x0-1 x1+1 0 tfinal]);
  h=colorbar('peer',data.axe2);
  set(h,'fontsize',7);
end

% Output
if data.ReturnFlag == 1
  out = pl;
elseif data.ReturnFlag == 2
  out.pl = pl;
  out.tl = tl;
  out.gridx = gridx;
else
  error(sprintf('Unknown ReturnFlag %g',ReturnFlag))
end