function [Mat] = getSysMat(Nx,ML,MR,dx,k,s0);

% Equations Physical domain
MMPD = speye(Nx,Nx); % Massmatrix
e = ones(Nx,1);
KKPD = 1/(dx^2).*spdiags([e -2*e e],-1:1,Nx,Nx) - k^2*speye(Nx,Nx);
MMPD = MMPD(2:end-1,:);
KKPD = KKPD(2:end-1,:);

P_PD   = sparse(ML+[1:Nx],[1:Nx],ones(1,Nx),Nx+ML+MR,Nx);
P_PDI  = sparse(ML+[2:Nx-1],[1:Nx-2],ones(1,Nx-2),Nx+ML+MR,Nx-2);
MMPDT = P_PDI*MMPD*P_PD'; 
KKPDT = P_PDI*KKPD*P_PD';

% Coupling Equations
MMC = sparse([ 1, dx/2, 0, 0, 0, 0;
	       0, 0 ,0, 0, dx/2, 1]);
KSC = sparse([ (s0^2-k^2), (-1/dx-dx*k^2/2)+s0, 1/dx, 0, 0, 0; ...
 	       0, 0, 0, 1/dx,  (-1/dx-dx*k^2/2)+s0, (s0^2-k^2)]);

P_C =  sparse([ML ML+1 ML+2 ML+Nx-1 ML+Nx ML+Nx+1],...
		      [1 : 6],ones(1,6),Nx+ML+MR,6);
P_CI = sparse([ML+1,ML+Nx],[1 2],ones(1,2),Nx+ML+MR,2);

MMCT = P_CI*MMC*P_C';
KSCT = P_CI*KSC*P_C';

% a0 Equation
MMA0 = sparse([1, 0, 0, 0, 0, 0;
	       0, 0, 0, 0, 0, 1]);
KSA0 = sparse([(s0^2-k^2), (4*s0^2), 2*s0, 0, 0, 0;
 	       0, 0, 0, 2*s0, (4*s0^2), (s0^2-k^2)]);

P_A0 =  sparse([ML-1 ML ML+1 ML+Nx ML+Nx+1 ML+Nx+2],...
		      [1 : 6],ones(1,6),Nx+ML+MR,6);
P_A0I = sparse([ML,ML+Nx+1],[1 2],ones(1,2),Nx+ML+MR,2);

MMA0T = P_A0I*MMA0*P_A0';
KSA0T = P_A0I*KSA0*P_A0';

% a1 Equation
MMA1 = sparse([1, -1, 0, 0, 0, 0;
	       0, 0, 0, 0, -1, 1]);
KSA1 = sparse([(s0^2-k^2), (3*s0^2+k^2) , 4*s0^2, 0, 0, 0;
 	       0, 0, 0, 4*s0^2, (3*s0^2+k^2), (s0^2-k^2)]);

P_A1 =  sparse([ML-2 ML-1 ML ML+Nx+1 ML+Nx+2 ML+Nx+3],...
		      [1 : 6],ones(1,6),Nx+ML+MR,6);
P_A1I = sparse([ML-1,ML+Nx+2],[1 2],ones(1,2),Nx+ML+MR,2);

MMA1T = P_A1I*MMA1*P_A1';
KSA1T = P_A1I*KSA1*P_A1';

% aj Equations
eL = ones(ML-1,1);
xAJL = spdiags([eL -2*eL eL],-1:1,ML-1,ML-1);
yAJL = spdiags([eL  2*eL eL],-1:1,ML-1,ML-1);
zAJL = spdiags([-eL 0*eL eL],-1:1,ML-1,ML-1);

MMAJL = xAJL;
KSAJL = s0^2*yAJL - k^2*xAJL;
MMAJL = MMAJL(1:end-1,:);
KSAJL = KSAJL(1:end-1,:);

P_AJL = sparse([1:ML-1],[1:ML-1],ones(1,ML-1),Nx+ML+MR,ML-1);
P_AJLI = sparse([1:ML-2],[1:ML-2],ones(1,ML-2),Nx+ML+MR,ML-2);
MMAJLT = P_AJLI*MMAJL*P_AJL';
KSAJLT = P_AJLI*KSAJL*P_AJL';

eR = ones(MR-1,1);
xAJR = spdiags([eR -2*eR eR],-1:1,MR-1,MR-1);
yAJR = spdiags([eR  2*eR eR],-1:1,MR-1,MR-1);
zAJR = spdiags([eR  0*eR -eR],-1:1,MR-1,MR-1);
MMAJR = xAJR;
KSAJR = s0^2*yAJR - k^2*xAJR ;
MMAJR = MMAJR(2:end,:);
KSAJR = KSAJR(2:end,:);

P_AJR =  sparse([Nx+ML+2:Nx+ML+MR],[1:MR-1],ones(1,MR-1),Nx+ML+MR,MR-1);
P_AJRI = sparse([Nx+ML+3:Nx+ML+MR],[1:MR-2],ones(1,MR-2),Nx+ML+MR,MR-2);
MMAJRT = P_AJRI*MMAJR*P_AJR';
KSAJRT = P_AJRI*KSAJR*P_AJR';

Mat.M = MMPDT+MMCT+MMA0T+MMA1T+MMAJLT+MMAJRT;
Mat.A = KKPDT+KSCT+KSA0T+KSA1T+KSAJLT+KSAJRT;
Mat.P_PD = P_PD;