function [SysMat] = getSysMatpmlfd(geo,PML)

x = geo.x;
dx = x(2)-x(1); 

np = size(x,2); % number of points

npml_l = PML.Left.M; % pml degrees of freedom
npml_r = PML.Right.M; % pml degrees of freedom

ndof = np+npml_l+npml_r;

gammapL = (1+i*PML.Left.sigma); % left damping factor
gammapR = (1+i*PML.Right.sigma); % right damping factor

e_pml_l = [gammapL*ones(npml_l+1,1); zeros(ndof-npml_l-1,1)];
e_pml_r = [zeros(ndof-npml_r-1,1); gammapR*ones(npml_r+1,1)];
e_comp = [zeros(npml_l,1); ones(np,1); zeros(npml_r,1)];
em = e_comp+e_pml_r+e_pml_l;
M = spdiags(em,0,ndof,ndof);

SysMat.M = M; % Mass matrix 

Vl=potential_func(x(1));   % Potential value on xl
Vr=potential_func(x(end)); % Potential value on xr  

pot = potential_func(x);

e_pml_l = [gammapL*Vl*ones(npml_l+1,1); zeros(ndof-npml_l-1,1)];
e_pml_r = [zeros(ndof-npml_r-1,1); gammapR*Vr*ones(npml_r+1,1)];
e_comp  = [zeros(npml_l,1); pot.'; zeros(npml_r,1)];
em = e_comp+e_pml_r+e_pml_l;
V = spdiags(em,0,ndof,ndof);

SysMat.V = V; % Potential

comp  = 1;
pml_l = 1;
pml_r = 1;

el_pml_l = pml_l * [(1/(1+i*PML.Left.sigma))*ones(npml_l-1,1); ...
		  (2/(1+i*PML.Left.sigma)); zeros(ndof-npml_l,1)];
el_comp  =  comp * [zeros(npml_l,1); ones(np-2,1); 2; zeros(npml_r+1,1)];
el_pml_r = pml_r * [zeros(ndof-npml_r-1,1); (1/(1+i*PML.Right.sigma))*ones(npml_r+1,1)];
el = el_pml_l + el_comp + el_pml_r;

em_pml_l = pml_l * [(-2/(1+i*PML.Left.sigma))*ones(npml_l+1,1);zeros(ndof-npml_l-1,1)];
em_comp  =  comp*[zeros(npml_l,1); -2*ones(np,1); zeros(npml_r,1)];
em_pml_r = pml_r * [zeros(ndof-npml_r-1,1); (-2/(1+i*PML.Right.sigma))*ones(npml_r+1,1)];
em = em_pml_l + em_comp + em_pml_r;

eu_pml_l = pml_l * [(1/(1+i*PML.Left.sigma))*ones(npml_l+1,1);zeros(ndof-npml_l-1,1)];
eu_comp  =  comp * [zeros(npml_l+1,1);2; ones(np-2,1); zeros(npml_r,1)];
eu_pml_r = pml_r * [zeros(ndof-npml_r,1);(2/(1+i*PML.Right.sigma)) ;(1/(1+i*PML.Right.sigma))*ones(npml_r-1,1)];
eu = eu_pml_l + eu_comp + eu_pml_r;

L = spdiags([el./dx^2, em./dx^2, eu./dx^2],[-1:1], np+npml_l+npml_r,np+npml_l+npml_r);

SysMat.L = L; % d_xx