function [A]=massMatrix3Pot(xl,xr,N,dx)
% Antoine-Besse July 2006
% Assembling of the finite element mass matrix
% for the potential term.
% Linear Finite Elements
% N : number of interior points
% dx : mesh size
% TBC on x0 and x1

% -------------------------------------------------------------------------
% The function f stands for the potential
f  = @(x) potential_func(x);

% -------------------------------------------------------------------------
% The following f function allows to verify that we have
% the good mass matrix if the potential equal one.
% f = @(x) 1;

% -------------------------------------------------------------------------
% The following f function allows to get a null potential.
% f=@(x) 0;

% -------------------------------------------------------------------------
% P3 finite element basis functions
g1 = @(x,k) -9/2*(x-(k-2/3)*dx).*(x-(k-1/3)*dx).*(x-(k-0)*dx)/dx^3;
g2 = @(x,k) 27/2*(x-(k-1)*dx).*(x-(k-1/3)*dx).*(x-(k-0)*dx)/dx^3;
g3 = @(x,k) -27/2*(x-(k-1)*dx).*(x-(k-2/3)*dx).*(x-(k-0)*dx)/dx^3;
g4 = @(x,k) 9/2*(x-(k-1)*dx).*(x-(k-2/3)*dx).*(x-(k-1/3)*dx)/dx^3;

e=zeros(N+2,1);
A=spdiags([e,e,e,e,e,e,e],[-3:3],N+2,N+2);

% -------------------------------------------------------------------------
% Mass matrix
j=0;
for jj=1:3:N,
    j=j+1;
    % Elementary matrix
    f11 = @(x) f(x).*g1(x-xl,j).*g1(x-xl,j);
    f12 = @(x) f(x).*g1(x-xl,j).*g2(x-xl,j);
    f13 = @(x) f(x).*g1(x-xl,j).*g3(x-xl,j);
    f14 = @(x) f(x).*g1(x-xl,j).*g4(x-xl,j);
    f22 = @(x) f(x).*g2(x-xl,j).*g2(x-xl,j);
    f23 = @(x) f(x).*g2(x-xl,j).*g3(x-xl,j);
    f24 = @(x) f(x).*g2(x-xl,j).*g4(x-xl,j);
    f33 = @(x) f(x).*g3(x-xl,j).*g3(x-xl,j);
    f34 = @(x) f(x).*g3(x-xl,j).*g4(x-xl,j);
    f44 = @(x) f(x).*g4(x-xl,j).*g4(x-xl,j);
    El11=quad(f11,xl+(j-1)*dx,xl+j*dx);
    El12=quad(f12,xl+(j-1)*dx,xl+j*dx);
    El13=quad(f13,xl+(j-1)*dx,xl+j*dx);
    El14=quad(f14,xl+(j-1)*dx,xl+j*dx);
    El22=quad(f22,xl+(j-1)*dx,xl+j*dx);
    El23=quad(f23,xl+(j-1)*dx,xl+j*dx);
    El24=quad(f24,xl+(j-1)*dx,xl+j*dx);
    El33=quad(f33,xl+(j-1)*dx,xl+j*dx);
    El34=quad(f34,xl+(j-1)*dx,xl+j*dx);
    El44=quad(f44,xl+(j-1)*dx,xl+j*dx);
    El1=[ El11, El12, El13, El14; ...,
          El12, El22, El23, El24; ...,
          El13, El23, El33, El34; ...
	  El14, El24, El34, El44];    
    A(jj:jj+3,jj:jj+3)=A(jj:jj+3,jj:jj+3)+El1;
end

